@@ -943,22 +943,22 @@ class Database:
         json1 = json1.replace('INT\"L','INTL')
         json1 = json1.replace('L\"OCCITANE','LOCCITANE')
 
-
         result = json.loads(json1)
 
         df = pd.DataFrame(result)
+
         df['ipo_date'] = pd.to_datetime(df['ipo_date'],format='%Y-%m-%d')
-        #df['ipo_date'] = df['ipo_date'].astype(str)
 
         df['share_issued'] = df['share_issued'].astype(str)
-        df['market_capital'] = df['market_capital'].astype(str)
-
         df['share_issued'] = df['share_issued'].str.replace('-','')
-        df['market_capital'] = df['market_capital'].str.replace('-','')
-        
-        df['share_issued'] = df['share_issued'].astype(int)
-        df['market_capital'] = df['market_capital'].astype(int)
-        df = df[['stock_name','code','price','PE','EPS','dividend','volume','turnover','share_issued','lot_size','market_capital','ipo_date','year_end_date']]
+        df['share_issued'] = df['share_issued'].astype('int64')
+
+        df['market_capital'] = df['share_issued'] * df['price']
+        df['market_capital'] = df['market_capital'].map(lambda x:round(x,0))
+        df['market_capital'] = df['market_capital'].astype('int64')
+
+        df = df[['code','stock_name','price','PE','EPS','dividend','volume','turnover','share_issued','lot_size','market_capital','ipo_date','year_end_date']]
+
         return df
 
     def get_hk_ipo_hist(self):
